@@ -1,10 +1,10 @@
 use aoko::no_std::{functions::ext::Utf8Ext, pipelines::pipe::Pipe};
-use num::BigUint;
+use ibig::UBig;
 
 pub mod cli;
 
 pub fn str_to_hex(s: &str) {
-    println!("str to hex: 0x{:0<64x}", s.as_bytes().pipe(BigUint::from_bytes_be))
+    println!("str to hex: 0x{:0<64x}", s.as_bytes().pipe(UBig::from_be_bytes))
 }
 
 pub fn hex_to_str(h: &str) {
